@@ -9,7 +9,7 @@ from numpy.testing import assert_array_equal
 
 from openmdao.components.interp_util.interp import InterpND
 from openmdao.components.interp_util.outofbounds_error import OutOfBoundsError
-from openmdao.utils.assert_utils import assert_rel_error, assert_equal_arrays
+from openmdao.utils.assert_utils import assert_near_equal, assert_equal_arrays
 
 def rel_error(actual, computed):
     return np.linalg.norm(actual - computed) / np.linalg.norm(actual)
@@ -47,7 +47,7 @@ class InterpNDStandaloneFeatureTestcase(unittest.TestCase):
                             20.96983509, 21.37579297, 21.94811407, 22.66809748, 23.51629844,
                             24.47327219, 25.51957398, 26.63575905, 27.80238264, 29.        ]])
 
-        assert_rel_error(self, akima_y.flatten(), y.flatten(), tolerance=1e-6)
+        assert_near_equal(akima_y.flatten(), y.flatten(), tolerance=1e-6)
 
     def test_interp_spline_akima_derivs(self):
         import numpy as np
@@ -73,7 +73,7 @@ class InterpNDStandaloneFeatureTestcase(unittest.TestCase):
                         [ 0.00000000e+00,  0.00000000e+00,  0.00000000e+00,
                             0.00000000e+00,  0.00000000e+00,  1.00000000e+00]])
 
-        assert_rel_error(self, deriv, dy_dycp, tolerance=1e-6)
+        assert_near_equal(deriv, dy_dycp, tolerance=1e-6)
 
     def test_interp_spline_bsplines(self):
         import numpy as np
@@ -100,7 +100,7 @@ class InterpNDStandaloneFeatureTestcase(unittest.TestCase):
                               20.4965297 , 21.13578243, 21.8400867 , 22.61430372, 23.46329467,
                               24.39192074, 25.40504312, 26.507523  , 27.70422156, 29.        ]])
 
-        assert_rel_error(self, akima_y.flatten(), y.flatten(), tolerance=1e-6)
+        assert_near_equal(akima_y.flatten(), y.flatten(), tolerance=1e-6)
 
     def test_table_interp(self):
         import numpy as np
@@ -124,8 +124,8 @@ class InterpNDStandaloneFeatureTestcase(unittest.TestCase):
         actual = np.array([6.73306794])
         deriv_actual = np.array([[ 0.06734927, 0.323 , -2.14]])
 
-        assert_rel_error(self, f, actual, tolerance=1e-7)
-        assert_rel_error(self, df_dx, deriv_actual, tolerance=1e-7)
+        assert_near_equal(f, actual, tolerance=1e-7)
+        assert_near_equal(df_dx, deriv_actual, tolerance=1e-7)
 
 
 class TestInterpNDPython(unittest.TestCase):
@@ -332,7 +332,7 @@ class TestInterpNDPython(unittest.TestCase):
             interp._xi = x
             dy = np.array([0.997901, 0.08915])
             interp._d_dx = dy
-            assert_rel_error(self, interp.gradient(x), dy, tolerance=1e-7)
+            assert_near_equal(interp.gradient(x), dy, tolerance=1e-7)
 
     def test_akima_interpolating_spline(self):
         n_cp = 80
@@ -457,7 +457,7 @@ class TestInterpNDPython(unittest.TestCase):
                           [ 0.00000000e+00,  0.00000000e+00,  0.00000000e+00,
                             0.00000000e+00,  0.00000000e+00,  1.00000000e+00]])
 
-        assert_rel_error(self, deriv, dy_dycp, tolerance=1e-6)
+        assert_near_equal(deriv, dy_dycp, tolerance=1e-6)
 
     def test_scipy_auto_reduce_spline_order(self):
         # if a spline method is used and spline_dim_error=False and a dimension
@@ -481,7 +481,7 @@ class TestInterpNDPython(unittest.TestCase):
         # should operate as normal
         x = np.array([0.5, 0, 1001])
         result = interp.interpolate(x)
-        assert_rel_error(self, result, -0.046325695741704434, tolerance=1e-5)
+        assert_near_equal(result, -0.046325695741704434, tolerance=1e-5)
 
         interp = InterpND(method='scipy_slinear', points=points, values=values)
         value1 = interp.interpolate(x)
@@ -583,4 +583,4 @@ class TestInterpNDPython(unittest.TestCase):
         self.assertTrue(str(cm.exception).startswith(msg))
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
