@@ -235,15 +235,6 @@ class TestFeature(unittest.TestCase):
 
         p = om.Problem()
 
-        ivc = om.IndepVarComp()
-        ivc.add_output(name='x', shape=(m,), units='m')
-        ivc.add_output(name='y', shape=(m,), units='m')
-        ivc.add_output(name='z', shape=(m,), units='m')
-
-        p.model.add_subsystem(name='ivc',
-                              subsys=ivc,
-                              promotes_outputs=['x', 'y', 'z'])
-
         mux_comp = p.model.add_subsystem(name='mux', subsys=om.MuxComp(vec_size=n))
 
         mux_comp.add_var('r', shape=(m,), axis=1, units='m')
@@ -252,25 +243,23 @@ class TestFeature(unittest.TestCase):
                               subsys=om.VectorMagnitudeComp(vec_size=m, length=n, in_name='r',
                                                             mag_name='r_mag', units='m'))
 
-        p.model.connect('x', 'mux.r_0')
-        p.model.connect('y', 'mux.r_1')
-        p.model.connect('z', 'mux.r_2')
         p.model.connect('mux.r', 'vec_mag_comp.r')
 
         p.setup()
 
-        p['x'] = 1 + np.random.rand(m)
-        p['y'] = 1 + np.random.rand(m)
-        p['z'] = 1 + np.random.rand(m)
+        p.set_val('mux.r_0', 1 + np.random.rand(m))
+        p.set_val('mux.r_1', 1 + np.random.rand(m))
+        p.set_val('mux.r_2', 1 + np.random.rand(m))
 
         p.run_model()
 
         # Verify the results against numpy.dot in a for loop.
         for i in range(n):
-            r_i = [p['x'][i], p['y'][i], p['z'][i]]
+            r_i = [p.get_val('mux.r_0')[i], p.get_val('mux.r_1')[i], p.get_val('mux.r_2')[i]]
             expected_i = np.sqrt(np.dot(r_i, r_i))
             assert_near_equal(p.get_val('vec_mag_comp.r_mag')[i], expected_i)
 
 
 if __name__ == '__main__':
     unittest.main()
+
