@@ -8,9 +8,11 @@ import numpy as np
 from numpy import ndarray, isscalar, atleast_1d, atleast_2d, promote_types
 from scipy.sparse import issparse
 
-from openmdao.core.system import System, _supported_methods, _DEFAULT_COLORING_META
+from openmdao.core.system import System, _supported_methods, _DEFAULT_COLORING_META, \
+    global_meta_names
+from openmdao.core.constants import INT_DTYPE
 from openmdao.jacobians.dictionary_jacobian import DictionaryJacobian
-from openmdao.vectors.vector import INT_DTYPE, _full_slice
+from openmdao.vectors.vector import _full_slice
 from openmdao.utils.units import valid_units
 from openmdao.utils.name_maps import rel_key2abs_key, abs_key2rel_key, rel_name2abs_name
 from openmdao.utils.mpi import MPI
@@ -19,13 +21,6 @@ from openmdao.utils.general_utils import format_as_float_or_array, ensure_compat
 import openmdao.utils.coloring as coloring_mod
 
 
-# the following metadata will be accessible for vars on all procs
-global_meta_names = {
-    'input': ('units', 'shape', 'size', 'distributed', 'tags', 'desc'),
-    'output': ('units', 'shape', 'size', 'desc',
-               'ref', 'ref0', 'res_ref', 'distributed', 'lower', 'upper', 'tags'),
-}
-
 _forbidden_chars = ['.', '*', '?', '!', '[', ']']
 _whitespace = set([' ', '\t', '\r', '\n'])
 
@@ -161,7 +156,6 @@ class Component(System):
         self._var_rel_names = {'input': [], 'output': []}
         self._var_rel2meta = {}
 
-        self._static_mode = False
         self._var_rel2meta.update(self._static_var_rel2meta)
         for type_ in ['input', 'output']:
             self._var_rel_names[type_].extend(self._static_var_rel_names[type_])
@@ -176,8 +170,6 @@ class Component(System):
                                                                 self._approx_schemes):
             raise RuntimeError("%s: num_par_fd is > 1 but no FD is active." % self.msginfo)
 
-        self._static_mode = True
-
         self._set_vector_class()
 
     def _set_vector_class(self):
@@ -221,12 +213,12 @@ class Component(System):
         global global_meta_names
         super(Component, self)._setup_var_data()
 
-        allprocs_abs_names = self._var_allprocs_abs_names
-        allprocs_abs_names_discrete = self._var_allprocs_abs_names_discrete
+        abs_names = self._var_abs_names = self._var_allprocs_abs_names
+        abs_names_discrete = self._var_abs_names_discrete = self._var_allprocs_abs_names_discrete
 
         allprocs_prom2abs_list = self._var_allprocs_prom2abs_list
 
-        abs2prom = self._var_abs2prom
+        abs2prom = self._var_allprocs_abs2prom = self._var_abs2prom
 
         allprocs_abs2meta = self._var_allprocs_abs2meta
         abs2meta = self._var_abs2meta
@@ -237,10 +229,9 @@ class Component(System):
         for type_ in ['input', 'output']:
             for prom_name in self._var_rel_names[type_]:
                 abs_name = prefix + prom_name
-                metadata = self._var_rel2meta[prom_name]
+                abs2meta[abs_name] = metadata = self._var_rel2meta[prom_name]
 
-                # Compute allprocs_abs_names
-                allprocs_abs_names[type_].append(abs_name)
+                abs_names[type_].append(abs_name)
 
                 # Compute allprocs_prom2abs_list, abs2prom
                 allprocs_prom2abs_list[type_][prom_name] = [abs_name]
@@ -251,18 +242,12 @@ class Component(System):
                     meta_name: metadata[meta_name]
                     for meta_name in global_meta_names[type_]
                 }
-                if type_ == 'input':
-                    src_indices = metadata['src_indices']
-                    allprocs_abs2meta[abs_name]['has_src_indices'] = src_indices is not None
-
-                # Compute abs2meta
-                abs2meta[abs_name] = metadata
 
             for prom_name, val in self._var_discrete[type_].items():
                 abs_name = prefix + prom_name
 
                 # Compute allprocs_abs_names_discrete
-                allprocs_abs_names_discrete[type_].append(abs_name)
+                abs_names_discrete[type_].append(abs_name)
 
                 # Compute allprocs_prom2abs_list, abs2prom
                 allprocs_prom2abs_list[type_][prom_name] = [abs_name]
@@ -272,10 +257,15 @@ class Component(System):
                 self._var_allprocs_discrete[type_][abs_name] = v = val.copy()
                 del v['value']
 
-        self._var_allprocs_abs2prom = abs2prom
+        for abs_name in abs_names['input']:
+            metadata = abs2meta[abs_name]
+            allprocs_abs2meta[abs_name]['has_src_indices'] = metadata['src_indices'] is not None
 
-        self._var_abs_names = allprocs_abs_names
-        self._var_abs_names_discrete = allprocs_abs_names_discrete
+            # ensure that if src_indices is a slice we reset it to that instead of
+            # the converted array value (in case this is a re-setup), so that we can
+            # re-convert using potentially different sizing information.
+            if metadata['src_slice'] is not None:
+                metadata['src_indices'] = metadata['src_slice']
 
         if self._var_discrete['input'] or self._var_discrete['output']:
             self._discrete_inputs = _DictValues(self._var_discrete['input'])
@@ -336,8 +326,6 @@ class Component(System):
 
         self._owned_sizes = self._var_sizes['nonlinear']['output']
 
-        self._setup_global_shapes()
-
     def _setup_partials(self):
         """
         Process all partials and approximations that the user declared.
@@ -460,28 +448,33 @@ class Component(System):
         if tags is not None and not isinstance(tags, (str, list)):
             raise TypeError('The tags argument should be a str or list')
 
+        src_slice = None
+        if src_indices is not None:
+            if _is_slicer_op(src_indices):
+                src_slice = src_indices
+                if flat_src_indices is not None:
+                    simple_warning(f"{self.msginfo}: Input '{name}' was added with slice "
+                                   "src_indices, so flat_src_indices is ignored.")
+                flat_src_indices = True
+            else:
+                src_indices = np.asarray(src_indices, dtype=INT_DTYPE)
+
         # value, shape: based on args, making sure they are compatible
         value, shape, src_indices = ensure_compatible(name, val, shape, src_indices)
-        distributed = self.options['distributed']
 
         metadata = {
             'value': value,
             'shape': shape,
             'size': np.prod(shape),
-            'src_indices': None,
+            'src_indices': src_indices,  # these will ultimately be converted to a flat index array
             'flat_src_indices': flat_src_indices,
+            'src_slice': src_slice,  # store slice def here, if any.  This is never overwritten
             'units': units,
             'desc': desc,
-            'distributed': distributed,
+            'distributed': self.options['distributed'],
             'tags': make_set(tags),
         }
 
-        if src_indices is not None:
-            if _is_slicer_op(src_indices):
-                metadata['src_indices'] = src_indices
-            else:
-                metadata['src_indices'] = np.asarray(src_indices, dtype=INT_DTYPE)
-
         if self._static_mode:
             var_rel2meta = self._static_var_rel2meta
             var_rel_names = self._static_var_rel_names
@@ -496,6 +489,8 @@ class Component(System):
         var_rel2meta[name] = metadata
         var_rel_names['input'].append(name)
 
+        self._var_added(name)
+
         return metadata
 
     def add_discrete_input(self, name, val, desc='', tags=None):
@@ -548,6 +543,8 @@ class Component(System):
 
         var_rel2meta[name] = self._var_discrete['input'][name] = metadata
 
+        self._var_added(name)
+
         return metadata
 
     def add_output(self, name, val=1.0, shape=None, units=None, res_units=None, desc='',
@@ -697,6 +694,8 @@ class Component(System):
         var_rel2meta[name] = metadata
         var_rel_names['output'].append(name)
 
+        self._var_added(name)
+
         return metadata
 
     def add_discrete_output(self, name, val, desc='', tags=None):
@@ -748,8 +747,22 @@ class Component(System):
 
         var_rel2meta[name] = self._var_discrete['output'][name] = metadata
 
+        self._var_added(name)
+
         return metadata
 
+    def _var_added(self, name):
+        """
+        Notify config that a variable has been added to this Component.
+
+        Parameters
+        ----------
+        name : str
+            Name of the added variable.
+        """
+        if self._problem_meta is not None and self._problem_meta['config_info'] is not None:
+            self._problem_meta['config_info']._var_added(self.pathname, name)
+
     def _update_dist_src_indices(self, abs_in2out, all_abs2meta, all_abs2idx, all_sizes):
         """
         Set default src_indices on distributed components for any inputs where they aren't set.
