@@ -206,10 +206,43 @@ class SerialTests(unittest.TestCase):
         try:
             p.setup()
         except Exception as err:
-            self.assertEqual(str(err), "Group (<model>): The following inputs, ['par.C1.x', 'par.C2.x'], promoted to 'x', are connected but their metadata entries ['value'] differ. Call <group>.set_input_defaults('x', value=?), where <group> is the Group named 'par' to remove the ambiguity.")
+            self.assertEqual(str(err), "Group (<model>): The following inputs, ['par.C1.x', 'par.C2.x'], promoted to 'x', are connected but their metadata entries ['value'] differ. Call <group>.set_input_defaults('x', val=?), where <group> is the Group named 'par' to remove the ambiguity.")
         else:
             self.fail("Exception expected.")
 
+    def test_obj_using_input_name(self):
+        class Phase(om.Group):
+            def setup(self):
+                self.add_subsystem('C1', om.ExecComp('y=.5*x'))
+                self.add_subsystem('C2', om.ExecComp('y=g*x'))
+                self.add_subsystem('C3', om.ExecComp('y=-x'))
+
+                # this is the culprit.  Bug when objective is added in group using input name
+                self.add_objective('C2.g')
+                self.add_design_var('C2.g')
+
+                self.connect('C1.y', 'C2.x')
+                self.connect('C2.y', 'C3.x')
+
+        p = om.Problem()
+        indep = p.model.add_subsystem('indep', om.IndepVarComp('x'))
+        indep.add_output('g')
+
+        p.model.add_subsystem('phase0', Phase())
+
+        p.model.connect('indep.x', 'phase0.C1.x')
+
+        p.model.add_design_var('indep.x')
+        p.model.add_constraint('phase0.C3.y', equals=0.0)
+
+        p.setup(force_alloc_complex=True)
+        p['indep.x'] = [9.9]
+        p['indep.g'] = 9.80665
+        p.run_model()
+        totals = p.check_totals(compact_print=True, method='cs', out_stream=None)
+        for key, meta in totals.items():
+            np.testing.assert_allclose(meta['abs error'][0], 0.)
+
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
 class MPITests(SerialTests):
@@ -247,3 +280,109 @@ class SrcIndicesTests(unittest.TestCase):
         prob.setup()
 
         prob.run_model()
+
+    def test_flat_src_inds_2_levels(self):
+        # this test passes if it doesn't raise an exception.
+        class Burn1(om.Group):
+            def setup(self):
+                self.add_subsystem('comp1', om.ExecComp(['y1=x*2'], y1=np.ones(4), x=np.ones(4)),
+                                promotes_outputs=['*'])
+
+                self.add_subsystem('comp2', om.ExecComp(['y2=x*2'], y2=np.ones(4), x=np.ones(4)),
+                                promotes_outputs=['*'])
+
+            def configure(self):
+                self.promotes('comp1', inputs=[('x', 'design:x')],
+                            src_indices=[0, 0, 0, 0], flat_src_indices=True)
+
+                self.set_input_defaults('design:x', 75.3)
+
+
+        class Traj(om.Group):
+            def setup(self):
+                self.add_subsystem('burn1', Burn1(),
+                                promotes_outputs=['*'])
+
+            def configure(self):
+                self.promotes('burn1', inputs=['design:x'],
+                            src_indices=[0, 0, 0, 0], flat_src_indices=True)
+
+        prob = om.Problem(model=Traj())
+
+        prob.setup()
+        prob.run_model()
+
+    def test_src_inds_2_subs(self):
+        # this test passes if it doesn't raise an exception.
+
+        class RHS(om.Group):
+
+            def initialize(self):
+                self.options.declare('size', 1)
+
+            def setup(self):
+                size = self.options['size']
+                self.add_subsystem('comp1', om.ExecComp(['y1=x*2'], y1=np.ones(size), x=np.ones(size)),
+                                promotes_inputs=['*'], promotes_outputs=['*'])
+
+                # test with second absolute path for 'x'
+                self.add_subsystem('comp2', om.ExecComp(['y2=x*2'], y2=np.ones(size), x=np.ones(size)),
+                                promotes_inputs=['*'], promotes_outputs=['*'])
+
+
+        class Phase(om.Group):
+            def setup(self):
+                self.add_subsystem('rhs', RHS(size=4))
+
+            def configure(self):
+                self.promotes('rhs', inputs=[('x', 'design:x')],
+                            src_indices=[0, 0, 0, 0], flat_src_indices=True)
+
+                self.set_input_defaults('design:x', 75.3)
+
+
+        class Traj(om.Group):
+            def setup(self):
+                self.add_subsystem('src', om.ExecComp(['q = b*3']))
+
+                self.add_subsystem('phase', Phase())
+
+                self.connect('src.q', 'phase.design:x')
+
+
+        prob = om.Problem(model=Traj())
+
+        prob.setup()
+
+        prob.run_model()
+
+    def test_sub_sub_promotes(self):
+        # this test passes if it doesn't raise an exception.
+        class Burn1(om.Group):
+            def setup(self):
+                self.add_subsystem('comp1', om.ExecComp(['y1=x*2'], y1=np.ones(4), x=np.ones(4)),
+                                promotes_outputs=['*'])
+                self.add_subsystem('comp2', om.ExecComp(['y2=x*2'], y2=np.ones(4), x=np.ones(4)),
+                                promotes_outputs=['*'])
+            def configure(self):
+                self.promotes('comp1', inputs=[('x', 'design:x')],
+                            src_indices=[0, 0, 0, 0], flat_src_indices=True)
+                self.set_input_defaults('design:x', 75.3)
+
+        class Phases(om.ParallelGroup):
+            def setup(self):
+                self.add_subsystem('burn1', Burn1(),
+                                promotes_outputs=['*'])
+
+        class Traj(om.Group):
+            def setup(self):
+                self.add_subsystem('phases', Phases(),
+                                promotes_outputs=['*'])
+            def configure(self):
+                # this promotes was leaving a leftover entry in _group_inputs that resulted
+                # from an earlier _setup_var_data call where the input in question had a different
+                # promoted name.
+                self.phases.promotes('burn1', inputs=['design:x'])
+
+        prob = om.Problem(model=Traj())
+        prob.setup()
