@@ -360,7 +360,7 @@ class TestGetSetVariables(unittest.TestCase):
         with self.assertRaises(RuntimeError) as cm:
             p.setup()
 
-        self.assertEqual(str(cm.exception), "Group (<model>): The following inputs, ['C1.x', 'C2.x', 'C3.x'], promoted to 'x', are connected but the metadata entries ['units'] differ. Call <group>.set_input_defaults('x', units=?), where <group> is the Group named '' to remove the ambiguity.")
+        self.assertEqual(str(cm.exception), "Group (<model>): The following inputs, ['C1.x', 'C2.x', 'C3.x'], promoted to 'x', are connected but their metadata entries ['units'] differ. Call <group>.set_input_defaults('x', units=?), where <group> is the model to remove the ambiguity.")
 
     def test_serial_multi_src_inds_units_setval_promoted(self):
         p = Problem()
