@@ -10,7 +10,7 @@ import time
 
 import numpy as np
 
-from openmdao.vectors.vector import INT_DTYPE
+from openmdao.core.constants import INT_DTYPE
 from openmdao.utils.general_utils import ContainsAll, simple_warning, prom2ivc_src_dict
 
 from openmdao.utils.mpi import MPI
@@ -71,6 +71,8 @@ class _TotalJacInfo(object):
     wrt_meta : dict
         Map of absolute output 'wrt' var name to tuples of the form
         (row/column slice, indices, distrib).
+    ivc_print_names :dict
+        Dictionary that maps auto_ivc names back to their promoted input names.
     output_list : list of str
         List of names of output variables for this total jacobian.  In fwd mode, outputs
         are responses.  In rev mode, outputs are design variables.
@@ -122,7 +124,7 @@ class _TotalJacInfo(object):
         driver = problem.driver
         prom2abs = problem.model._var_allprocs_prom2abs_list['output']
         prom2abs_in = problem.model._var_allprocs_prom2abs_list['input']
-        conns = problem._metadata['connections']
+        conns = problem.model._conn_global_abs_in2out
 
         self.model = model = problem.model
         self.comm = problem.comm
@@ -141,6 +143,8 @@ class _TotalJacInfo(object):
         if isinstance(of, str):
             of = [of]
 
+        # convert designvar and response dicts to use src names
+        # keys will all be absolute names after conversion
         design_vars = prom2ivc_src_dict(driver._designvars)
         responses = prom2ivc_src_dict(driver._responses)
 
@@ -148,27 +152,29 @@ class _TotalJacInfo(object):
             raise RuntimeError("Derivative support has been turned off but compute_totals "
                                "was called.")
 
-        driver_wrt = list(design_vars)
+        driver_wrt = list(driver._designvars)
         driver_of = driver._get_ordered_nl_responses()
 
         # Convert of and wrt names from promoted to absolute
         if wrt is None:
             if driver_wrt:
-                prom_wrt = list(driver._designvars)
+                prom_wrt = driver_wrt
             else:
                 raise RuntimeError("Driver is not providing any design variables "
                                    "for compute_totals.")
         else:
-            # Convert wrt inputs to auto_ivc output names.\
             prom_wrt = wrt
 
+        # Convert 'wrt' names from promoted to absolute
         wrt = []
+        self.ivc_print_names = {}
         for name in prom_wrt:
-            if not use_abs_names and name in prom2abs:
+            if name in prom2abs:
                 wrt_name = prom2abs[name][0]
             elif name in prom2abs_in:
                 in_abs = prom2abs_in[name][0]
                 wrt_name = conns[in_abs]
+                self.ivc_print_names[wrt_name] = name
             else:
                 wrt_name = name
             wrt.append(wrt_name)
@@ -182,14 +188,16 @@ class _TotalJacInfo(object):
         else:
             prom_of = of
 
+        # Convert 'of' names from promoted to absolute
         of = []
         for name in prom_of:
-            if not use_abs_names and name in prom2abs:
+            if name in prom2abs:
                 of_name = prom2abs[name][0]
             elif name in prom2abs_in:
                 # An auto_ivc design var can be used as a response too.
                 in_abs = prom2abs_in[name][0]
                 of_name = conns[in_abs]
+                self.ivc_print_names[of_name] = name
             else:
                 of_name = name
             of.append(of_name)
@@ -242,7 +250,8 @@ class _TotalJacInfo(object):
                 self.simul_coloring = driver._coloring_info['coloring']
 
                 # if we don't get wrt and of from driver, turn off coloring
-                if self.simul_coloring is not None and (wrt != driver_wrt or of != driver_of):
+                if self.simul_coloring is not None and \
+                   (prom_wrt != driver_wrt or prom_of != driver_of):
                     msg = ("compute_totals called using a different list of design vars and/or "
                            "responses than those used to define coloring, so coloring will "
                            "be turned off.\ncoloring design vars: %s, current design vars: "
@@ -395,17 +404,18 @@ class _TotalJacInfo(object):
         J : ndarray
             Array jacobian.
         wrt : iter of str
-            Absolute names of input vars.
+            Absolute names of 'with respect to' vars.
         prom_wrt : iter of str
-            Promoted names of input vars.
+            Promoted names of 'with respect to' vars.
         of : iter of str
             Absolute names of output vars.
         prom_of : iter of str
             Promoted names of output vars.
         wrt_meta : dict
-            Dict mapping input name to array jacobian slice, indices, and distrib.
+            Dict mapping absolute 'with respect to' name to array jacobian slice, indices,
+            and distrib.
         of_meta : dict
-            Dict mapping output name to array jacobian slice, indices, and distrib.
+            Dict mapping absolute output name to array jacobian slice, indices, and distrib.
         return_format : str
             Indicates the desired form of the returned jacobian.
 
@@ -484,6 +494,10 @@ class _TotalJacInfo(object):
 
         for name in input_list:
             rhsname = 'linear'
+            if name not in abs2meta:
+                # could be promoted input name
+                abs_in = model._var_allprocs_prom2abs_list['input'][name][0]
+                name = model._conn_global_abs_in2out[abs_in]
             in_var_meta = abs2meta[name]
 
             if name in vois:
@@ -510,11 +524,8 @@ class _TotalJacInfo(object):
                         self.par_deriv[parallel_deriv_color].append(name)
 
                         print_name = name
-                        if name.startswith('_auto_ivc'):
-                            conns = model._problem_meta['connections']
-                            for src, tgt in conns.items():
-                                if tgt == name:
-                                    print_name = model._var_allprocs_abs2prom['input'][src]
+                        if name in self.ivc_print_names:
+                            print_name = self.ivc_print_names[name]
 
                         self.par_deriv_printnames[parallel_deriv_color].append(print_name)
 
@@ -1379,7 +1390,10 @@ class _TotalJacInfo(object):
                                                                                   mode=self.mode):
                                     print("   {}".format(local_ind))
                             else:
-                                print("('{0}', [{1}])".format(key, inds))
+                                print_key = key
+                                if key in self.ivc_print_names:
+                                    print_key = self.ivc_print_names[key]
+                                print("('{0}', [{1}])".format(print_key, inds))
 
                         sys.stdout.flush()
                         t0 = time.time()
@@ -1623,10 +1637,10 @@ class _TotalJacInfo(object):
         Print out the derivatives when debug_print is True.
         """
         if self.return_format == 'dict':
-            J = self.J_dict
-            for of in self.of:
-                for wrt in self.wrt:
-                    pprint.pprint({(of, wrt): J[of][wrt]})
+            J_dict = self.J_dict
+            for of, wrt_dict in J_dict.items():
+                for wrt, J_sub in wrt_dict.items():
+                    pprint.pprint({(of, wrt): J_sub})
         else:
             J = self.J
             for i, of in enumerate(self.of):
